# megadetector-utils

This package is a pip-installable version of <b>just the utility code</b> from the [MegaDetector](https://github.com/agentmorris/MegaDetector/?tab=readme-ov-file#megadetector) repository.  In other words, this package contains everything in the [megadetector](https://pypi.org/project/megadetector/) package <i>except</i> the PyTorch/YOLO dependencies.  If you want to run MegaDetector, you don't want the megadetector-utils package.  If you just want to use the tools for, e.g., postprocessing, manipulating large sets of camera trap images, etc., this package may be useful; it's a much quicker install than the megadetector package.

Version numbers are generally synchronized with the megadetector package.

## Installation

Install with:

`pip install megadetector-utils`

## Package reference

See [megadetector.readthedocs.io](https://megadetector.readthedocs.io).

## Contact

Contact <a href="cameratraps@lila.science">cameratraps@lila.science</a> with questions.

## Gratuitous animal picture

<img src="https://github.com/agentmorris/MegaDetector/raw/main/images/orinoquia-thumb-web_detections.jpg"><br/>Image credit University of Minnesota, from the [Orinoquía Camera Traps](http://lila.science/datasets/orinoquia-camera-traps/) data set.
